How a document breaks its lines.
Installed once at boot like the typography, and read at paint.
Structs
- Layout
- How a document breaks its lines.
Functions
- set_
layout markdown::set_layout(cx, my_layout)— call once at boot.
How a document breaks its lines.
Installed once at boot like the typography, and read at paint.
markdown::set_layout(cx, my_layout) — call once at boot.