pub enum MarkdownEvent {
Show 15 variants
Start(MarkdownTag),
End(MarkdownTagEnd),
Text,
SubstitutedText(String),
Code,
SubstitutedCode(String),
Html,
InlineHtml,
FootnoteReference(SharedString),
SoftBreak,
HardBreak,
Rule,
TaskListMarker(bool),
RootStart,
RootEnd(usize),
}Expand description
A static-lifetime equivalent of pulldown_cmark::Event so we can cache the parse result for rendering without resorting to unsafe lifetime coercion.
Variants
Start(MarkdownTag)
Start of a tagged element. Events that are yielded after this event
and before its corresponding End event are inside this element.
Start and end events are guaranteed to be balanced.
End(MarkdownTagEnd)
End of a tagged element.
Text
Text that uses the associated range from the markdown source.
SubstitutedText(String)
Text that differs from the markdown source - typically due to substitution of HTML entities and smart punctuation.
Code
An inline code node.
SubstitutedCode(String)
An inline code node that differs from the markdown source due to escape decoding.
Html
An HTML node.
InlineHtml
An inline HTML node.
FootnoteReference(SharedString)
A reference to a footnote with given label, which may or may not be defined
by an event with a Tag::FootnoteDefinition tag. Definitions and references to them may
occur in any order.
SoftBreak
A soft line break.
HardBreak
A hard line break.
Rule
A horizontal ruler.
TaskListMarker(bool)
A task list marker, rendered as a checkbox in HTML. Contains a true when it is checked.
RootStart
Start of a root-level block (a top-level structural element like a paragraph, heading, list, etc.).
RootEnd(usize)
End of a root-level block. Contains the root block index.