pub enum MarkdownTag {
Show 23 variants
Paragraph,
Heading {
level: HeadingLevel,
id: Option<SharedString>,
classes: Vec<SharedString>,
attrs: Vec<(SharedString, Option<SharedString>)>,
},
BlockQuote(Option<BlockQuoteKind>),
CodeBlock {
kind: CodeBlockKind,
metadata: CodeBlockMetadata,
},
HtmlBlock,
List(Option<u64>),
Item,
FootnoteDefinition(SharedString),
Table(Vec<Alignment>),
TableHead,
TableRow,
TableCell,
Emphasis,
Strong,
Strikethrough,
Superscript,
Subscript,
Link {
link_type: LinkType,
dest_url: SharedString,
title: SharedString,
id: SharedString,
},
Image {
link_type: LinkType,
dest_url: SharedString,
title: SharedString,
id: SharedString,
},
MetadataBlock(MetadataBlockKind),
DefinitionList,
DefinitionListTitle,
DefinitionListDefinition,
}Expand description
Tags for elements that can contain other elements.
Variants
Paragraph
A paragraph of text and other inline elements.
Heading
A heading, with optional identifier, classes and custom attributes.
The identifier is prefixed with # and the last one in the attributes
list is chosen, classes are prefixed with . and custom attributes
have no prefix and can optionally have a value (myattr o myattr=myvalue).
Fields
level: HeadingLevelid: Option<SharedString>classes: Vec<SharedString>attrs: Vec<(SharedString, Option<SharedString>)>The first item of the tuple is the attr and second one the value.
BlockQuote(Option<BlockQuoteKind>)
CodeBlock
A code block.
HtmlBlock
A HTML block.
List(Option<u64>)
A list. If the list is ordered the field indicates the number of the first item. Contains only list items.
Item
A list item.
FootnoteDefinition(SharedString)
A footnote definition. The value contained is the footnote’s label by which it can be referred to.
Table(Vec<Alignment>)
A table. Contains a vector describing the text-alignment for each of its columns.
TableHead
A table header. Contains only TableCells. Note that the table body starts immediately
after the closure of the TableHead tag. There is no TableBody tag.
TableRow
A table row. Is used both for header rows as body rows. Contains only TableCells.
TableCell
Emphasis
Strong
Strikethrough
Superscript
Subscript
Link
A link.
Fields
dest_url: SharedStringtitle: SharedStringid: SharedStringIdentifier of reference links, e.g. world in the link [hello][world].
Image
An image. The first field is the link type, the second the destination URL and the third is a title, the fourth is the link identifier.
Fields
dest_url: SharedStringtitle: SharedStringid: SharedStringIdentifier of reference links, e.g. world in the link [hello][world].
MetadataBlock(MetadataBlockKind)
A metadata block.
DefinitionList
DefinitionListTitle
DefinitionListDefinition