pub fn set_source_style(
cx: &mut App,
style: impl Fn(&Theme) -> SourceStyle + 'static,
)Expand description
Resolve styles at paint so host colors follow theme changes.
pub fn set_source_style(
cx: &mut App,
style: impl Fn(&Theme) -> SourceStyle + 'static,
)Resolve styles at paint so host colors follow theme changes.