pub struct Markdown { /* private fields */ }Implementations
Sourceimpl Markdown
impl Markdown
pub fn new(source: SharedString, cx: &mut Context<'_, Self>) -> Self
pub fn new_with_options( source: SharedString, options: MarkdownOptions, cx: &mut Context<'_, Self>, ) -> Self
pub fn new_text(source: SharedString, cx: &mut Context<'_, Self>) -> Self
pub fn is_parsing(&self) -> bool
pub fn scroll_to_heading( &mut self, slug: &str, cx: &mut Context<'_, Self>, ) -> Option<usize>
pub fn source(&self) -> &SharedString
Sourcepub fn first_code_block_language(&self) -> Option<&'static Language>
pub fn first_code_block_language(&self) -> Option<&'static Language>
Resolves the first fenced code block’s language, if any (see module
docs for the static-registry resolution this uses instead of an
Arc<Language>-based per-document resolution).
pub fn append(&mut self, text: &str, cx: &mut Context<'_, Self>)
pub fn replace( &mut self, source: impl Into<SharedString>, cx: &mut Context<'_, Self>, )
pub fn request_autoscroll_to_source_index( &mut self, source_index: usize, cx: &mut Context<'_, Self>, )
pub fn set_active_root_for_source_index( &mut self, source_index: Option<usize>, cx: &mut Context<'_, Self>, )
pub fn reset(&mut self, source: SharedString, cx: &mut Context<'_, Self>)
pub fn escape(s: &str) -> Cow<'_, str>
pub fn selected_text(&self) -> Option<String>
pub fn set_search_highlights( &mut self, highlights: Vec<Range<usize>>, active: Option<usize>, cx: &mut Context<'_, Self>, )
pub fn clear_search_highlights(&mut self, cx: &mut Context<'_, Self>)
pub fn set_active_search_highlight( &mut self, active: Option<usize>, cx: &mut Context<'_, Self>, )
pub fn search_highlights(&self) -> &[Range<usize>]
pub fn active_search_highlight(&self) -> Option<usize>
Returns the URL of the link that was most recently right-clicked, if any. This is set during a right-click mouse-down event and can be read by parent views to include a “Copy Link” item in their context menus.
Returns the rendered (plain) text that was selected when the most recent context menu invocation happened.
Returns the raw markdown source that was selected when the most recent context menu invocation happened.